@@ -6,7 +6,7 @@ Kafka::Connection - Object interface to connect to a kafka cluster.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Connection> version 0.8013 .
+This documentation refers to C<Kafka::Connection> version 0.9000 .
 
 =cut
 
@@ -20,7 +20,7 @@ use warnings;
 
 our $DEBUG = 0;
 
-our $VERSION = '0.8013';
+our $VERSION = '0.9000';
 
 use Exporter qw(
     import
@@ -40,10 +40,8 @@ use Data::Validate::IP qw(
     is_ipv6
 );
 use Const::Fast;
-use List::MoreUtils qw(
-    all
-);
 use List::Util qw(
+    all
     shuffle
 );
 use Params::Util qw(
@@ -85,8 +83,12 @@ use Kafka qw(
     $ERROR_REPLICA_NOT_AVAILABLE
     $ERROR_MESSAGE_SIZE_TOO_LARGE
     $ERROR_STALE_CONTROLLER_EPOCH_CODE
+    $ERROR_GROUP_LOAD_IN_PROGRESS_CODE
     $ERROR_OFFSET_METADATA_TOO_LARGE_CODE
-    $ERROR_CONSUMER_COORDINATOR_NOT_AVAILABLE_CODE
+    $ERROR_GROUP_COORDINATOR_NOT_AVAILABLE_CODE
+    $ERROR_NOT_COORDINATOR_FOR_GROUP_CODE
+    $ERROR_NOT_ENOUGH_REPLICAS_CODE
+    $ERROR_NOT_ENOUGH_REPLICAS_AFTER_APPEND_CODE
 
     $ERROR_CANNOT_BIND
     $ERROR_CANNOT_GET_METADATA
@@ -96,9 +98,12 @@ use Kafka qw(
     $ERROR_MISMATCH_ARGUMENT
     $ERROR_MISMATCH_CORRELATIONID
     $ERROR_NO_KNOWN_BROKERS
-    $ERROR_RESPOSEMESSAGE_NOT_RECEIVED
+    $ERROR_RESPONSEMESSAGE_NOT_RECEIVED
     $ERROR_SEND_NO_ACK
     $ERROR_UNKNOWN_APIKEY
+
+    $IP_V4
+    $IP_V6
     $KAFKA_SERVER_PORT
     $NOT_SEND_ANY_RESPONSE
     $RECEIVE_MAX_ATTEMPTS
@@ -172,7 +177,7 @@ The main features of the C<Kafka::Connection> class are:
 
 =item *
 
-Provides API for communication with Kafka 0.8 cluster.
+Provides API for communication with Kafka 0.9 cluster.
 
 =item *
 
@@ -223,20 +228,36 @@ const our %RETRY_ON_ERRORS => (
 #   $ERROR_NO_ERROR                         => 1,   # 0 - No error
     $ERROR_UNKNOWN                          => 1,   # -1 - An unexpected server error
 #   $ERROR_OFFSET_OUT_OF_RANGE              => 1,   # 1 - The requested offset is outside the range of offsets available at the server for the given topic/partition
-#   $ERROR_INVALID_MESSAGE                  => 1,   # 2 - Message contents does not match its control sum
-#   $ERROR_UNKNOWN_TOPIC_OR_PARTITION       => 1,   # 3 - Unknown topic or partition
+   $ERROR_INVALID_MESSAGE                  => 1,   # 2 - Retriable - Message contents does not match its control sum
+   $ERROR_UNKNOWN_TOPIC_OR_PARTITION       => 1,   # 3 - Retriable - Unknown topic or partition
 #   $ERROR_INVALID_MESSAGE_SIZE             => 1,   # 4 - Message has invalid size
-    $ERROR_LEADER_NOT_AVAILABLE             => 1,   # 5 - Unable to write due to ongoing Kafka leader selection
-    $ERROR_NOT_LEADER_FOR_PARTITION         => 1,   # 6 - Server is not a leader for partition
-    $ERROR_REQUEST_TIMED_OUT                => 1,   # 7 - Request time-out
+    $ERROR_LEADER_NOT_AVAILABLE             => 1,   # 5 - Retriable - Unable to write due to ongoing Kafka leader selection
+    $ERROR_NOT_LEADER_FOR_PARTITION         => 1,   # 6 - Retriable - Server is not a leader for partition
+    $ERROR_REQUEST_TIMED_OUT                => 1,   # 7 - Retriable - Request time-out
     $ERROR_BROKER_NOT_AVAILABLE             => 1,   # 8 - Broker is not available
     $ERROR_REPLICA_NOT_AVAILABLE            => 1,   # 9 - Replica not available
 #   $ERROR_MESSAGE_SIZE_TOO_LARGE           => 1,   # 10 - Message is too big
     $ERROR_STALE_CONTROLLER_EPOCH_CODE      => 1,   # 11 - Stale Controller Epoch Code
 #   $ERROR_OFFSET_METADATA_TOO_LARGE_CODE   => 1,   # 12 - Specified metadata offset is too big
-#    $ERROR_LOAD_IN_PROGRESS_CODE            => 1,   # 14 - Still loading offsets
-    $ERROR_CONSUMER_COORDINATOR_NOT_AVAILABLE_CODE  => 1,   # 15 - Topic has not yet been created
-#    $ERROR_NOT_COORDINATOR_FOR_CONSUMER_CODE    => 1,   # 16 - Request for a consumer group that it is not a coordinator for
+    $ERROR_GROUP_LOAD_IN_PROGRESS_CODE      => 1,   # 14 - Retriable - Still loading offsets
+    $ERROR_GROUP_COORDINATOR_NOT_AVAILABLE_CODE => 1,   # 15 - Retriable - Topic has not yet been created
+    $ERROR_NOT_COORDINATOR_FOR_GROUP_CODE   => 1,   # 16 - Retriable - Request for a consumer group that it is not a coordinator for
+
+#    $ERROR_INVALID_TOPIC_CODE               => 1,   # 17 - A request which attempts to access an invalid topic
+#    $ERROR_RECORD_LIST_TOO_LARGE_CODE       => 1,   # 18 - A message batch in a produce request exceeds the maximum configured segment size
+    $ERROR_NOT_ENOUGH_REPLICAS_CODE         => 1,   # 19 - Retriable - The number of in-sync replicas is lower than the configured minimum and requiredAcks is -1
+    $ERROR_NOT_ENOUGH_REPLICAS_AFTER_APPEND_CODE    => 1,   # 20 - Retriable - The message was written to the log, but with fewer in-sync replicas than required
+#    $ERROR_INVALID_REQUIRED_ACKS_CODE       => 1,   # 21 - The requested requiredAcks is invalid (anything other than -1, 1, or 0)
+#    $ERROR_ILLEGAL_GENERATION_CODE          => 1,   # 22 - The generation id provided in the request is not the current generation
+#    $ERROR_INCONSISTENT_GROUP_PROTOCOL_CODE => 1,   # 23 - The member provides a protocol type or set of protocols which is not compatible with the current group
+#    $ERROR_INVALID_GROUP_ID_CODE            => 1,   # 24 - The groupId is empty or null
+#    $ERROR_UNKNOWN_MEMBER_ID_CODE           => 1,   # 25 - The memberId is not in the current generation
+#    $ERROR_INVALID_SESSION_TIMEOUT_CODE     => 1,   # 26 - The requested session timeout is outside of the allowed range on the broker
+#    $ERROR_REBALANCE_IN_PROGRESS_CODE       => 1,   # 27 - The coordinator has begun rebalancing the group
+#    $ERROR_INVALID_COMMIT_OFFSET_SIZE_CODE  => 1,   # 28 - An offset commit was rejected because of oversize metadata
+#    $ERROR_TOPIC_AUTHORIZATION_FAILED_CODE  => 1,   # 29 - The client is not authorized to access the requested topic
+#    $ERROR_GROUP_AUTHORIZATION_FAILED_CODE  => 1,   # 30 - The client is not authorized to access a particular groupId
+#    $ERROR_CLUSTER_AUTHORIZATION_FAILED_CODE    => 1,   # 31 - The client is not authorized to use an inter-broker or administrative API
 );
 
 #-- constructor ----------------------------------------------------------------
@@ -282,6 +303,16 @@ of Kafka servers. This list will be used to locate the new leader if the server
 via C<host =E<gt> $host> and C<port =E<gt> $port> arguments becomes unavailable. Either C<host>
 or C<broker_list> must be supplied.
 
+=item C<ip_version =E<gt> $ip_version>
+
+Specify version of IP for interpreting of passed IP address and resolving of host name.
+
+Optional, undefined by default, which works in the following way: version of IP address
+is detected automatically, host name is resolved into IPv4 address.
+
+See description of L<$IP_V4|Kafka::IO/$IP_V4>, L<$IP_V6|Kafka::IO/$IP_V6>
+in C<Kafka> L<EXPORT|Kafka/EXPORT>.
+
 =item C<timeout =E<gt> $timeout>
 
 Optional, default = C<$Kafka::REQUEST_TIMEOUT>.
@@ -380,6 +411,7 @@ sub new {
         port                    => $KAFKA_SERVER_PORT,
         broker_list             => [],
         timeout                 => $REQUEST_TIMEOUT,
+        ip_version              => undef,
         CorrelationId           => undef,
         SEND_MAX_ATTEMPTS       => $SEND_MAX_ATTEMPTS,
         RECEIVE_MAX_ATTEMPTS    => $RECEIVE_MAX_ATTEMPTS,
@@ -424,6 +456,10 @@ sub new {
     $self->_error( $ERROR_MISMATCH_ARGUMENT, 'MaxLoggedErrors' )
         unless defined( _NONNEGINT( $self->{MaxLoggedErrors} ) );
 
+    my $ip_version = $self->{ip_version};
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'ip_version ('.( $ip_version // '<undef>' ).')' )
+        unless ( !defined( $ip_version ) || ( defined( _NONNEGINT( $ip_version ) ) && ( $ip_version == $IP_V4 || $ip_version == $IP_V6 ) ) );
+
     $self->{_metadata} = {};                # {
                                             #   TopicName => {
                                             #       Partition   => {
@@ -526,7 +562,7 @@ Consult Kafka "Wire protocol" documentation for more details about metadata stru
 sub get_metadata {
     my ( $self, $topic ) = @_;
 
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$topic' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'topic' )
         unless !defined( $topic ) || ( ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic ) );
 
     $self->_update_metadata( $topic )
@@ -738,7 +774,7 @@ sub receive_response_to_request {
                     if ( length( $$encoded_response_ref ) > 4 ) {   # MessageSize => int32
                         $response = $protocol{ $api_key }->{decode}->( $encoded_response_ref );
                     } else {
-                        $self->_error( $ERROR_RESPOSEMESSAGE_NOT_RECEIVED );
+                        $self->_error( $ERROR_RESPONSEMESSAGE_NOT_RECEIVED );
                     }
                 }
 
@@ -805,9 +841,9 @@ The C<$topic> must be a normal non-false string of non-zero length.
 sub exists_topic_partition {
     my ( $self, $topic, $partition ) = @_;
 
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $topic )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'topic' )
         unless defined( $topic ) && ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $partition )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'partition' )
         unless defined( $partition ) && isint( $partition ) && $partition >= 0;
 
     unless ( %{ $self->{_metadata} } ) {    # the first request
@@ -1025,7 +1061,7 @@ sub _update_metadata {
             return $self->_attempt_update_metadata( $is_recursive_call, $topic, undef, $ERROR_NO_KNOWN_BROKERS );
         } else {
             # FATAL error
-            $self->_error( $ERROR_NO_KNOWN_BROKERS, "topic = '$topic'" );
+            $self->_error( $ERROR_NO_KNOWN_BROKERS, "topic = '".( $topic // '<undef>' )."'" );
         }
     }
 
@@ -1088,7 +1124,7 @@ sub _update_metadata {
 
     %$received_metadata
         # FATAL error
-        or $self->_error( $ERROR_CANNOT_GET_METADATA, "topic = '$topic'" );
+        or $self->_error( $ERROR_CANNOT_GET_METADATA, "topic = '".( $topic // '<undef>' )."'" );
 
     # Update metadata for received topics
     $self->{_metadata}->{ $_ }  = $received_metadata->{ $_ } foreach keys %{ $received_metadata };
@@ -1116,7 +1152,7 @@ sub _attempt_update_metadata {
         return( 1 ) if $self->_update_metadata( $topic, 1 );
     }
     # FATAL error
-    $self->_error( $error_code, "topic = '$topic'", defined( $partition ) ? ", partition = $partition" : () );
+    $self->_error( $error_code, "topic = '".( $topic // '<undef>' )."'", defined( $partition ) ? ", partition = $partition" : () );
 
     return;
 }
@@ -1159,6 +1195,7 @@ sub _connectIO {
                 host        => $server_data->{host},
                 port        => $server_data->{port},
                 timeout     => $self->{timeout},
+                ip_version  => $self->{ip_version},
             );
             $server_data->{error} = undef;
         } catch {
@@ -1392,7 +1429,7 @@ Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013 by TrackingSoft LLC.
+Copyright (C) 2012-2016 by TrackingSoft LLC.
 
 This package is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See I<perlartistic> at
