@@ -6,7 +6,7 @@ Kafka::Consumer - Perl interface for Kafka consumer client.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Consumer> version 0.8013 .
+This documentation refers to C<Kafka::Consumer> version 0.9000 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.8013';
+our $VERSION = '0.9000';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -160,7 +160,7 @@ Provides Kafka FETCH and OFFSETS requests.
 
 =item *
 
-Supports parsing the Apache Kafka 0.8 Wire Format protocol.
+Supports parsing the Apache Kafka 0.9 Wire Format protocol.
 
 =item *
 
@@ -357,13 +357,13 @@ sub fetch {
     my ( $self, $topic, $partition, $start_offset, $max_size, $_return_all ) = @_;
     # Special argument: $_return_all - return redundant messages sent out of a compressed package posts
 
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$topic' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'topic' )
         unless defined( $topic ) && ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$partition' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'partition' )
         unless defined( $partition ) && isint( $partition ) && $partition >= 0;
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$offset' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'offset' )
         unless defined( $start_offset ) && ( ( _isbig( $start_offset ) && $start_offset >= 0 ) || defined( _NONNEGINT( $start_offset ) ) );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, "\$max_size ($max_size)" )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, "max_size ($max_size)" )
         unless ( !defined( $max_size ) || ( ( _isbig( $max_size ) || _POSINT( $max_size ) ) && $max_size >= $MESSAGE_SIZE_OVERHEAD && $max_size <= $MAX_INT32 ) );
 
     my $request = {
@@ -479,13 +479,13 @@ Optional. The argument must be a positive int32 signed integer.
 sub offsets {
     my ( $self, $topic, $partition, $time, $max_number ) = @_;
 
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$topic' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'topic' )
         unless defined( $topic) && ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$partition' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'partition' )
         unless defined( $partition ) && isint( $partition ) && $partition >= 0;
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, '$time' )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'time' )
         unless defined( $time ) && ( _isbig( $time ) || isint( $time ) ) && $time >= $RECEIVE_EARLIEST_OFFSETS;
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, "\$max_number ($max_number)" )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, "max_number ($max_number)" )
         unless !defined( $max_number ) || ( _POSINT( $max_number ) && $max_number <= $MAX_INT32 );
 
     my $request = {
@@ -644,7 +644,7 @@ Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013 by TrackingSoft LLC.
+Copyright (C) 2012-2016 by TrackingSoft LLC.
 
 This package is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See I<perlartistic> at
