@@ -6,7 +6,7 @@ Kafka::IO - Interface to network communication with the Apache Kafka server.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::IO> version 0.8013 .
+This documentation refers to C<Kafka::IO> version 0.9000 .
 
 =cut
 
@@ -20,7 +20,7 @@ use warnings;
 
 our $DEBUG = 0;
 
-our $VERSION = '0.8013';
+our $VERSION = '0.9000';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -45,6 +45,8 @@ use Socket qw(
     AF_INET
     AF_INET6
     IPPROTO_TCP
+    NI_NUMERICHOST
+    NIx_NOSERV
     PF_INET
     PF_INET6
     SOCK_STREAM
@@ -52,6 +54,8 @@ use Socket qw(
     SO_ERROR
     SO_RCVTIMEO
     SO_SNDTIMEO
+    getaddrinfo
+    getnameinfo
     inet_aton
     inet_pton
     inet_ntop
@@ -70,6 +74,9 @@ use Kafka qw(
     $ERROR_CANNOT_SEND
     $ERROR_MISMATCH_ARGUMENT
     $ERROR_NOT_BINARY_STRING
+    $ERROR_INCOMPATIBLE_HOST_IP_VERSION
+    $IP_V4
+    $IP_V6
     $KAFKA_SERVER_PORT
     $REQUEST_TIMEOUT
 );
@@ -128,7 +135,7 @@ Provides an object oriented API for communication with Kafka.
 
 =item *
 
-This class allows you to create Kafka 0.8 clients.
+This class allows you to create Kafka 0.9 clients.
 
 =back
 
@@ -150,8 +157,8 @@ C<new()> takes arguments in key-value pairs. The following arguments are current
 
 =item C<host =E<gt> $host>
 
-C<$host> is an Apache Kafka host to connect to. It can be a hostname or the
-IP-address in the IPv4 or IPv6 form (for example '127.0.0.1', '0:0:0:0:0:0:0:1' or '::1').
+C<$host> is Kafka host to connect to. It can be a host name or an IP-address in
+IPv4 or IPv6 form (for example '127.0.0.1', '0:0:0:0:0:0:0:1' or '::1').
 
 =item C<port =E<gt> $port>
 
@@ -164,13 +171,6 @@ from the L<Kafka|Kafka> module.
 
 =item C<timeout =E<gt> $timeout>
 
-Optional, default = C<$REQUEST_TIMEOUT>.
-
-C<$timeout> specifies how long we wait for remote server to respond before
-the IO object disconnects and throws internal exception.
-The C<$timeout> is specified in seconds (could be any integer or floating-point type)
-and supported by C<gethostbyname()>, connect, blocking receive and send calls.
-
 C<$REQUEST_TIMEOUT> is the default timeout that can be imported from the L<Kafka|Kafka> module.
 
 Special behavior when C<timeout> is set to C<undef>:
@@ -189,6 +189,20 @@ Default C<$REQUEST_TIMEOUT> is used for the rest of IO operations.
 
 =back
 
+=over 3
+
+=item C<ip_version =E<gt> $ip_version>
+
+Force version of IP protocol for resolving host name (or interpretation of passed address).
+
+Optional, undefined by default, which works in the following way: version of IP address
+is detected automatically, host name is resolved into IPv4 address.
+
+See description of L<$IP_V4|Kafka::IO/$IP_V4>, L<$IP_V6|Kafka::IO/$IP_V6>
+in C<Kafka> L<EXPORT|Kafka/EXPORT>.
+
+=back
+
 =cut
 sub new {
     my ( $class, @args ) = @_;
@@ -197,6 +211,7 @@ sub new {
         host        => q{},
         timeout     => $REQUEST_TIMEOUT,
         port        => $KAFKA_SERVER_PORT,
+        ip_version  => undef,
         af          => '',  # Address family constant
         pf          => '',  # Protocol family constant
         ip          => '',  # Human-readable textual representation of the ip address
@@ -356,8 +371,7 @@ sub _connect {
     my $timeout = $self->{timeout};
 
     my $ip = '';
-    if ( is_ipv4( $name ) || is_ipv6( $name ) ) {
-        $self->_get_family( $name );
+    if ( $self->_get_family( $name ) ) {
         $ip = $self->{ip} = $name;
     } else {
         if ( defined $timeout ) {
@@ -411,6 +425,7 @@ sub _connect {
             }
         } else {
             $ip = $self->_gethostbyname( $name );
+            die( "not resolve a host name to the IP address: $name\n" ) unless $ip;
         }
     }
 
@@ -484,7 +499,7 @@ sub _get_timeval {
     my $intval = int( $timeout );                               # sec
     my $fraction = int( ( $timeout - $intval ) * 1_000_000 );   # ms
 
-    if ( $Config{osname} eq 'netbsd' && $Config{osvers} >= 6.0 && $Config{longsize} == 4 ) {
+    if ( $Config{osname} eq 'netbsd' && _major_osvers() >= 6 && $Config{longsize} == 4 ) {
         if ( defined $Config{use64bitint} ) {
             $timeout = pack( 'QL', int( $timeout ), $fraction );
         } else {
@@ -504,12 +519,50 @@ sub _get_timeval {
     return $timeout;
 }
 
+sub _major_osvers {
+    my $osvers = $Config{osvers};
+    my ( $major_osvers ) = $osvers =~ /^(\d+)/;
+    $major_osvers += 0;
+
+    return $major_osvers;
+}
+
 sub _gethostbyname {
     my ( $self, $name ) = @_;
 
-    $self->_get_family( $name );
-    my $ipaddr = gethostbyname( $name );
-    $self->{ip} = $ipaddr ? inet_ntop( $self->{af}, $ipaddr ) : '';
+    my $is_v4_fqdn = 1;
+    $self->{ip} = '';
+
+    my $ip_version = $self->{ip_version};
+    if ( defined( $ip_version ) && $ip_version == $IP_V6 ) {
+        my ( $err, @addrs ) = getaddrinfo(
+            $name,
+            '',     # not interested in the service name
+            {
+                family      => AF_INET6,
+                socktype    => SOCK_STREAM,
+                protocol    => IPPROTO_TCP,
+            },
+        );
+        return( $self->{ip} ) if $err;
+
+        $is_v4_fqdn = 0;
+        for my $addr ( @addrs ) {
+            my ( $err, $ipaddr ) = getnameinfo( $addr->{addr}, NI_NUMERICHOST, NIx_NOSERV );
+            next if $err;
+
+            $self->{af} = AF_INET6;
+            $self->{pf} = PF_INET6;
+            $self->{ip} = $ipaddr;
+            last;
+        }
+    }
+
+    if ( $is_v4_fqdn && ( !defined( $ip_version ) || $ip_version == $IP_V4 ) ) {
+        if ( my $ipaddr = gethostbyname( $name ) ) {
+            $self->{ip} = inet_ntop( $self->{af}, $ipaddr );
+        }
+    }
 
     return $self->{ip};
 }
@@ -517,15 +570,38 @@ sub _gethostbyname {
 sub _get_family {
     my ( $self, $name ) = @_;
 
-    if ( is_ipv6( $name ) ) {
+    my $is_ip;
+    my $ip_version = $self->{ip_version} // 0;
+    if ( ( ( $is_ip = is_ipv6( $name ) ) && !$ip_version ) || $ip_version == $IP_V6 ) {
+        $self->_error( $ERROR_INCOMPATIBLE_HOST_IP_VERSION, "ip_version = $ip_version, host = $name" )
+            if
+                   $ip_version
+                && (
+                        ( !$is_ip && is_ipv4( $name ) )
+                    || ( $is_ip && $ip_version == $IP_V4 )
+                )
+        ;
+
         $self->{af} = AF_INET6;
         $self->{pf} = PF_INET6;
-    } else {
+    } elsif ( ( ( $is_ip = is_ipv4( $name ) ) && !$ip_version ) || $ip_version == $IP_V4 ) {
+        $self->_error( $ERROR_INCOMPATIBLE_HOST_IP_VERSION, "ip_version = $ip_version, host = $name" )
+            if
+                   $ip_version
+                && (
+                        ( !$is_ip && is_ipv6( $name ) )
+                    || ( $is_ip && $ip_version == $IP_V6 )
+                )
+        ;
+
+        $self->{af} = AF_INET;
+        $self->{pf} = PF_INET;
+    } elsif ( !$ip_version ) {
         $self->{af} = AF_INET;
         $self->{pf} = PF_INET;
     }
 
-    return;
+    return $is_ip;
 }
 
 # Show additional debugging information
@@ -702,7 +778,7 @@ Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013 by TrackingSoft LLC.
+Copyright (C) 2012-2016 by TrackingSoft LLC.
 
 This package is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See I<perlartistic> at
