@@ -6,7 +6,7 @@ Kafka::Producer - Perl interface for Kafka producer client.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Producer> version 0.8013 .
+This documentation refers to C<Kafka::Producer> version 0.9000 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.8013';
+our $VERSION = '0.9000';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -43,7 +43,9 @@ use Kafka qw(
     $ERROR_CANNOT_GET_METADATA
     $ERROR_MISMATCH_ARGUMENT
     $REQUEST_TIMEOUT
+    $NOT_SEND_ANY_RESPONSE
     $WAIT_WRITTEN_TO_LOCAL_LOG
+    $BLOCK_UNTIL_IS_COMMITTED
 );
 use Kafka::Connection;
 use Kafka::Exceptions;
@@ -191,8 +193,6 @@ the server will wait until the data is written to the local log before sending a
 If it is C<$BLOCK_UNTIL_IS_COMMITTED>
 the server will block until the message is committed by all in sync replicas before sending a response.
 
-For any number > 1 the server will block waiting for this number of acknowledgements to occur.
-
 C<$NOT_SEND_ANY_RESPONSE>, C<$WAIT_WRITTEN_TO_LOCAL_LOG>, C<$BLOCK_UNTIL_IS_COMMITTED>
 can be imported from the L<Kafka|Kafka> module.
 
@@ -236,11 +236,21 @@ sub new {
         unless isint( $self->{CorrelationId} ) && $self->{CorrelationId} <= $MAX_CORRELATIONID;
     $self->_error( $ERROR_MISMATCH_ARGUMENT, 'ClientId' )
         unless ( $self->{ClientId} eq q{} || defined( _STRING( $self->{ClientId} ) ) ) && !utf8::is_utf8( $self->{ClientId} );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'RequiredAcks' )
-        unless defined( $self->{RequiredAcks} ) && isint( $self->{RequiredAcks} ) && $self->{RequiredAcks} <= $MAX_INT16;
     $self->_error( $ERROR_MISMATCH_ARGUMENT, 'Timeout ('.( $self->{Timeout} // '<undef>' ).')' )
         unless _NUMBER( $self->{Timeout} ) && $self->{Timeout} <= $MAX_INT32;
 
+    my $required_acks = $self->{RequiredAcks};
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'RequiredAcks' )
+        unless
+               defined( $required_acks )
+            && isint( $required_acks )
+            && (
+                   $required_acks == $NOT_SEND_ANY_RESPONSE
+                || $required_acks == $WAIT_WRITTEN_TO_LOCAL_LOG
+                || $required_acks == $BLOCK_UNTIL_IS_COMMITTED
+            )
+    ;
+
     return $self;
 }
 
@@ -305,15 +315,15 @@ sub send {
 
     $key //= q{};
 
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $topic )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'topic' )
         unless defined( $topic ) && ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $partition )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'partition' )
         unless defined( $partition ) && isint( $partition ) && $partition >= 0;
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $messages )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'messages' )
         unless defined( _STRING( $messages ) ) || _ARRAY0( $messages );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $key )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'key' )
         unless ( $key eq q{} || defined( _STRING( $key ) ) ) && !utf8::is_utf8( $key );
-    $self->_error( $ERROR_MISMATCH_ARGUMENT, $compression_codec )
+    $self->_error( $ERROR_MISMATCH_ARGUMENT, 'compression_codec' )
         unless ( !defined( $compression_codec ) || $known_compression_codecs{ $compression_codec } );
 
     $messages = [ $messages ] unless ref( $messages );
@@ -480,7 +490,7 @@ Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013 by TrackingSoft LLC.
+Copyright (C) 2012-2016 by TrackingSoft LLC.
 
 This package is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See I<perlartistic> at
